@@ -5,7 +5,7 @@ from statshog import defaults
 from statshog.client import StatsClient
 
 
-statsd = None
+statsd: StatsClient = None # type: ignore
 
 if statsd is None:
     host = getattr(settings, "STATSD_HOST", defaults.HOST)
@@ -13,6 +13,7 @@ if statsd is None:
     prefix = getattr(settings, "STATSD_PREFIX", defaults.PREFIX)
     maxudpsize = getattr(settings, "STATSD_MAXUDPSIZE", defaults.MAXUDPSIZE)
     ipv6 = getattr(settings, "STATSD_IPV6", defaults.IPV6)
+    telegraf = getattr(settings, "STATSD_TELEGRAF", defaults.TELEGRAF)
     statsd = StatsClient(
-        host=host, port=port, prefix=prefix, maxudpsize=maxudpsize, ipv6=ipv6
+        host=host, port=port, prefix=prefix, maxudpsize=maxudpsize, ipv6=ipv6, telegraf=telegraf
     )
